@@ -5,10 +5,11 @@ import os
 import re
 import shlex
 import subprocess
-from collections import deque
+from collections import defaultdict, deque
 from dataclasses import dataclass
 from datetime import datetime
-from itertools import chain, takewhile
+from functools import partial
+from itertools import takewhile
 
 from pathspec import PathSpec
 from pkgcore.ebuild import cpv
@@ -20,7 +21,7 @@ from pkgcore.restrictions import packages
 from snakeoil.cli import arghparse
 from snakeoil.contexts import GitStash
 from snakeoil.klass import jit_attr
-from snakeoil.mappings import OrderedSet
+from snakeoil.mappings import ImmutableDict, OrderedSet
 from snakeoil.osutils import pjoin
 from snakeoil.process import CommandNotFound, find_binary
 from snakeoil.strings import pluralism
@@ -32,6 +33,10 @@ from ..log import logger
 from . import caches
 
 
+# ignore global user and system git config
+NO_CONFIG_ENV = ImmutableDict({'GIT_CONFIG_GLOBAL': '', 'GIT_CONFIG_SYSTEM': ''})
+
+
 @dataclass(frozen=True, eq=False)
 class GitCommit:
     """Git commit objects."""
@@ -40,7 +45,7 @@ class GitCommit:
     author: str
     committer: str
     message: tuple
-    pkgs: tuple = ()
+    pkgs: ImmutableDict = ImmutableDict()
 
     def __str__(self):
         return self.hash
@@ -81,7 +86,7 @@ class GitLog:
         self._running = False
         self.proc = subprocess.Popen(
             cmd, cwd=path,
-            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=NO_CONFIG_ENV)
 
     def __iter__(self):
         return self
@@ -179,8 +184,15 @@ class GitRepoCommits(_ParseGitRepo):
         author = next(self.git_log)
         committer = next(self.git_log)
         message = list(takewhile(lambda x: x != '\x00', self.git_log))
-        pkgs = list(chain.from_iterable(pkgs for _, pkgs in self.changes))
-        return GitCommit(commit_hash, commit_time, author, committer, message, pkgs)
+        pkgs = defaultdict(set)
+        for status, atoms in self.changes:
+            if status == 'R':
+                old, new = atoms
+                pkgs['A'].add(new)
+                pkgs['D'].add(old)
+            else:
+                pkgs[status].update(atoms)
+        return GitCommit(commit_hash, commit_time, author, committer, message, ImmutableDict(pkgs))
 
 
 class GitRepoPkgs(_ParseGitRepo):
@@ -287,14 +299,27 @@ class GitRemovedRepo(GitChangedRepo):
     _status_filter = {'D'}
 
 
-class _ScanCommits(argparse.Action):
-    """Argparse action that enables scannings against git commits."""
+class _ScanGit(argparse.Action):
+    """Argparse action that enables scanning against git commits or staged changes."""
 
-    def generate_restrictions(self, parser, namespace, diff_cmd):
+    def __init__(self, *args, staged=False, **kwargs):
+        super().__init__(*args, **kwargs)
+        if staged:
+            default_ref = 'HEAD'
+            diff_cmd = ['git', 'diff-index', '--name-only', '--cached', '-z']
+        else:
+            default_ref = 'origin..HEAD'
+            diff_cmd = ['git', 'diff-tree', '-r', '--name-only', '-z']
+
+        self.staged = staged
+        self.default_ref = default_ref
+        self.diff_cmd = diff_cmd
+
+    def generate_restrictions(self, parser, namespace, ref):
         """Generate restrictions for a given diff command."""
         try:
             p = subprocess.run(
-                diff_cmd,
+                self.diff_cmd + [ref],
                 stdout=subprocess.PIPE, stderr=subprocess.PIPE,
                 cwd=namespace.target_repo.location, check=True, encoding='utf8')
         except FileNotFoundError as e:
@@ -343,42 +368,20 @@ class _ScanCommits(argparse.Action):
             s = pluralism(namespace.targets)
             parser.error(f'{option_string} is mutually exclusive with target{s}: {targets}')
 
-        # determine target git ref
-        ref = value if value is not None else 'origin..HEAD'
+        if not self.staged:
+            # avoid circular import issues
+            from .. import objects
+            # enable git checks
+            namespace.enabled_checks.update(objects.CHECKS.select(GitCommitsCheck).values())
+
+        # determine target ref
+        ref = value if value is not None else self.default_ref
         setattr(namespace, self.dest, ref)
 
         # generate scanning restrictions
-        diff_cmd = ['git', 'diff-tree', '-r', '--name-only', '-z', ref]
-        namespace.restrictions = self.generate_restrictions(parser, namespace, diff_cmd)
-
-        # avoid circular import issues
-        from .. import objects
-        # enable git checks
-        namespace.enabled_checks.update(objects.CHECKS.select(GitCommitsCheck).values())
-
-        # ignore uncommitted changes during scan
-        namespace.contexts.append(GitStash(namespace.target_repo.location))
-
-
-class _ScanStaged(_ScanCommits):
-    """Argparse action that enables scanning against staged changes."""
-
-    def __call__(self, parser, namespace, value, option_string=None):
-        if namespace.targets:
-            targets = ' '.join(namespace.targets)
-            s = pluralism(namespace.targets)
-            parser.error(f'{option_string} is mutually exclusive with target{s}: {targets}')
-
-        # determine target git ref
-        ref = value if value is not None else 'HEAD'
-        setattr(namespace, self.dest, ref)
-
-        # generate scanning restrictions
-        diff_cmd = ['git', 'diff-index', '--name-only', '--cached', '-z', ref]
-        namespace.restrictions = self.generate_restrictions(parser, namespace, diff_cmd)
-
-        # ignore uncommitted changes during scan
-        namespace.contexts.append(GitStash(namespace.target_repo.location, staged=True))
+        namespace.restrictions = self.generate_restrictions(parser, namespace, ref)
+        # ignore irrelevant changes during scan
+        namespace.contexts.append(GitStash(namespace.target_repo.location, staged=self.staged))
 
 
 class GitAddon(caches.CachedAddon):
@@ -394,8 +397,8 @@ class GitAddon(caches.CachedAddon):
     upstream.
 
     Additionally, the origin/HEAD ref must exist. If it doesn't, running ``git
-    fetch origin`` should create it. Otherwise, using ``git remote set-head
-    origin master`` or similar will also create the reference.
+    remote set-head origin master`` or similar for other branches will create
+    it.
     """
 
     # cache registry
@@ -407,7 +410,7 @@ class GitAddon(caches.CachedAddon):
         git_opts = group.add_mutually_exclusive_group()
         git_opts.add_argument(
             '--commits', nargs='?', default=False, metavar='tree-ish',
-            action=arghparse.Delayed, target=_ScanCommits, priority=10,
+            action=arghparse.Delayed, target=_ScanGit, priority=10,
             help='determine scan targets from unpushed commits',
             docs="""
                 Targets are determined from the committed changes compared to a
@@ -420,7 +423,7 @@ class GitAddon(caches.CachedAddon):
             """)
         git_opts.add_argument(
             '--staged', nargs='?', default=False, metavar='tree-ish',
-            action=arghparse.Delayed, target=_ScanStaged, priority=10,
+            action=arghparse.Delayed, target=partial(_ScanGit, staged=True), priority=10,
             help='determine scan targets from staged changes',
             docs="""
                 Targets are determined using all staged changes for the git
@@ -462,7 +465,7 @@ class GitAddon(caches.CachedAddon):
         return False
 
     @staticmethod
-    def _get_commit_hash(path, commit='origin/HEAD'):
+    def _get_commit_hash(path, commit):
         """Retrieve a git repo's commit hash for a specific commit object."""
         try:
             p = subprocess.run(
@@ -473,6 +476,30 @@ class GitAddon(caches.CachedAddon):
             raise GitError(f'failed retrieving commit hash for git repo: {path!r}')
         return p.stdout.strip()
 
+    @staticmethod
+    def _get_current_branch(path, commit='HEAD'):
+        """Retrieve a git repo's current branch for a specific commit object."""
+        try:
+            p = subprocess.run(
+                ['git', 'rev-parse', '--abbrev-ref', commit],
+                stdout=subprocess.PIPE, stderr=subprocess.DEVNULL,
+                cwd=path, check=True, encoding='utf8')
+        except subprocess.CalledProcessError:
+            raise GitError(f'failed retrieving branch for git repo: {path!r}')
+        return p.stdout.strip()
+
+    @staticmethod
+    def _get_default_branch(path):
+        """Retrieve a git repo's default branch used with origin remote."""
+        try:
+            p = subprocess.run(
+                ['git', 'symbolic-ref', 'refs/remotes/origin/HEAD'],
+                stdout=subprocess.PIPE, stderr=subprocess.DEVNULL,
+                cwd=path, check=True, encoding='utf8')
+        except subprocess.CalledProcessError:
+            raise GitError(f'failed retrieving branch for git repo: {path!r}')
+        return p.stdout.strip().split('/')[-1]
+
     @staticmethod
     def pkg_history(repo, commit_range, data=None, local=False, verbosity=-1):
         """Create or update historical package data for a given commit range."""
@@ -499,7 +526,15 @@ class GitAddon(caches.CachedAddon):
         """Update related cache and push updates to disk."""
         for repo in self.options.target_repo.trees:
             try:
-                commit = self._get_commit_hash(repo.location)
+                branch = self._get_current_branch(repo.location)
+                default_branch = self._get_default_branch(repo.location)
+                # skip cache usage when not running on the default branch
+                if branch != default_branch:
+                    logger.debug(
+                        'skipping %s git repo cache update on '
+                        'non-default branch %r', repo, branch)
+                    continue
+                commit = self._get_commit_hash(repo.location, 'origin/HEAD')
             except GitError:
                 continue
 
@@ -519,6 +554,7 @@ class GitAddon(caches.CachedAddon):
                 else:
                     data = git_cache.data
                     commit_range = f'{git_cache.commit}..origin/HEAD'
+
                 try:
                     self.pkg_history(
                         repo, commit_range, data=data,
@@ -550,8 +586,8 @@ class GitAddon(caches.CachedAddon):
         data = {}
 
         try:
-            origin = self._get_commit_hash(target_repo.location)
-            head = self._get_commit_hash(target_repo.location, commit='HEAD')
+            origin = self._get_commit_hash(target_repo.location, 'origin/HEAD')
+            head = self._get_commit_hash(target_repo.location, 'HEAD')
             if origin != head:
                 data = self.pkg_history(target_repo, 'origin/HEAD..HEAD', local=True)
         except GitError as e:
@@ -565,8 +601,8 @@ class GitAddon(caches.CachedAddon):
         commits = ()
 
         try:
-            origin = self._get_commit_hash(target_repo.location)
-            head = self._get_commit_hash(target_repo.location, commit='HEAD')
+            origin = self._get_commit_hash(target_repo.location, 'origin/HEAD')
+            head = self._get_commit_hash(target_repo.location, 'HEAD')
             if origin != head:
                 commits = GitRepoCommits(target_repo.location, 'origin/HEAD..HEAD')
         except GitError as e:
