@@ -24,8 +24,10 @@ from . import Check
 from .visibility import FakeConfigurable
 
 
-class MissingLicenseFile(results.VersionResult, results.Error):
-    """Used license(s) have no matching license file(s)."""
+class _LicenseResult(results.VersionResult):
+    """Generic license result."""
+
+    license_type = None
 
     def __init__(self, licenses, **kwargs):
         super().__init__(**kwargs)
@@ -35,7 +37,19 @@ class MissingLicenseFile(results.VersionResult, results.Error):
     def desc(self):
         s = pluralism(self.licenses)
         licenses = ', '.join(self.licenses)
-        return f'no matching license file{s}: {licenses}'
+        return f'{self.license_type} license{s}: {licenses}'
+
+
+class UnknownLicense(_LicenseResult, results.Error):
+    """License usage with no matching license file."""
+
+    license_type = 'unknown'
+
+
+class DeprecatedLicense(_LicenseResult, results.Warning):
+    """Deprecated license usage."""
+
+    license_type = 'deprecated'
 
 
 class MissingLicense(results.VersionResult, results.Error):
@@ -80,8 +94,8 @@ class LicenseCheck(Check):
     """LICENSE validity checks."""
 
     known_results = frozenset([
-        InvalidLicense, MissingLicense, MissingLicenseFile, UnnecessaryLicense,
-        UnstatedIuse, MissingLicenseRestricts,
+        InvalidLicense, MissingLicense, UnknownLicense, DeprecatedLicense,
+        UnnecessaryLicense, UnstatedIuse, MissingLicenseRestricts,
     ])
 
     # categories for ebuilds that can lack LICENSE settings
@@ -91,8 +105,10 @@ class LicenseCheck(Check):
 
     def __init__(self, *args, use_addon):
         super().__init__(*args)
+        repo = self.options.target_repo
         self.iuse_filter = use_addon.get_filter('license')
-        self.eula = self.options.target_repo.licenses.groups.get('EULA')
+        self.deprecated = repo.licenses.groups.get('DEPRECATED', frozenset())
+        self.eula = repo.licenses.groups.get('EULA', frozenset())
         self.mirror_restricts = frozenset(['fetch', 'mirror'])
 
     def _required_licenses(self, license_group, nodes, restricts=None):
@@ -140,62 +156,73 @@ class LicenseCheck(Check):
         if not licenses:
             if pkg.category not in self.unlicensed_categories:
                 yield MissingLicense(pkg=pkg)
+        elif pkg.category in self.unlicensed_categories:
+            yield UnnecessaryLicense(pkg=pkg)
         else:
-            licenses.difference_update(pkg.repo.licenses)
-            if licenses:
-                yield MissingLicenseFile(sorted(licenses), pkg=pkg)
-            elif pkg.category in self.unlicensed_categories:
-                yield UnnecessaryLicense(pkg=pkg)
+            if unknown := licenses - set(pkg.repo.licenses):
+                yield UnknownLicense(sorted(unknown), pkg=pkg)
+            if deprecated := licenses & self.deprecated:
+                yield DeprecatedLicense(sorted(deprecated), pkg=pkg)
 
 
-class _UseFlagsResult(results.VersionResult, results.Error):
+class _UseFlagsResult(results.VersionResult):
     """Generic USE flags result."""
 
+    flag_type = None
+
     def __init__(self, flags, **kwargs):
         super().__init__(**kwargs)
         self.flags = tuple(flags)
 
-    def _desc(self, flag_type):
+    @property
+    def desc(self):
         s = pluralism(self.flags)
         flags = ', '.join(map(repr, sorted(self.flags)))
-        return f'{flag_type} USE flag{s}: {flags}'
+        return f'{self.flag_type} USE flag{s}: {flags}'
 
 
-class InvalidUseFlags(_UseFlagsResult):
+class InvalidUseFlags(_UseFlagsResult, results.Error):
     """Package IUSE contains invalid USE flags."""
 
-    @property
-    def desc(self):
-        return self._desc('invalid')
+    flag_type = 'invalid'
 
 
-class UnknownUseFlags(_UseFlagsResult):
+class UnknownUseFlags(_UseFlagsResult, results.Error):
     """Package IUSE contains unknown USE flags."""
 
-    @property
-    def desc(self):
-        return self._desc('unknown')
+    flag_type = 'unknown'
+
+
+class BadDefaultUseFlags(_UseFlagsResult, results.Error):
+    """Package IUSE contains bad default USE flags."""
+
+    flag_type = 'bad default'
 
 
 class IuseCheck(Check):
     """IUSE validity checks."""
 
     required_addons = (addons.UseAddon,)
-    known_results = frozenset([InvalidUseFlags, UnknownUseFlags])
+    known_results = frozenset([InvalidUseFlags, UnknownUseFlags, BadDefaultUseFlags])
+    use_expand_groups = ('cpu_flags',)
 
     def __init__(self, *args, use_addon):
         super().__init__(*args)
         self.iuse_handler = use_addon
+        self.valid_use = atom_mod.valid_use_flag.match
+        self.bad_defaults = tuple(['-'] + [f'+{x}_' for x in self.use_expand_groups])
 
     def feed(self, pkg):
-        invalid = sorted(x for x in pkg.iuse_stripped if not atom_mod.valid_use_flag.match(x))
-        if invalid:
+        if invalid := sorted(x for x in pkg.iuse_stripped if not self.valid_use(x)):
             yield InvalidUseFlags(invalid, pkg=pkg)
 
+        if pkg.eapi.options.iuse_defaults and (bad_defaults := sorted(
+                x for x in pkg.iuse if x.startswith(self.bad_defaults) and len(x) > 1)):
+            yield BadDefaultUseFlags(bad_defaults, pkg=pkg)
+
         if not self.iuse_handler.ignore:
             unknown = pkg.iuse_stripped.difference(self.iuse_handler.allowed_iuse(pkg))
-            unknown = unknown.difference(invalid)
-            if unknown:
+            if unknown := unknown.difference(invalid):
                 yield UnknownUseFlags(sorted(unknown), pkg=pkg)
 
 
@@ -225,6 +252,19 @@ class BannedEapi(_EapiResult, results.Error):
     _type = 'banned'
 
 
+class StableKeywordsOnTestingEapi(results.VersionResult, results.Error):
+    """Package has stable keywords on EAPI marked as testing-only."""
+
+    def __init__(self, eapi, keywords, **kwargs):
+        super().__init__(**kwargs)
+        self.eapi = str(eapi)
+        self.keywords = tuple(keywords)
+
+    @property
+    def desc(self):
+        return f"stable keywords ({' '.join(self.keywords)}) on testing EAPI {self.eapi}"
+
+
 class UnsupportedEclassEapi(results.VersionResult, results.Warning):
     """Ebuild inherits an eclass with outdated @SUPPORTED_EAPIS."""
 
@@ -241,7 +281,8 @@ class UnsupportedEclassEapi(results.VersionResult, results.Warning):
 class EapiCheck(Check):
     """Scan for packages with banned or deprecated EAPIs."""
 
-    known_results = frozenset([DeprecatedEapi, BannedEapi, UnsupportedEclassEapi])
+    known_results = frozenset([DeprecatedEapi, BannedEapi, UnsupportedEclassEapi,
+                               StableKeywordsOnTestingEapi])
     required_addons = (addons.eclass.EclassAddon,)
 
     def __init__(self, *args, eclass_addon):
@@ -255,6 +296,11 @@ class EapiCheck(Check):
         elif eapi_str in self.options.target_repo.config.eapis_deprecated:
             yield DeprecatedEapi(pkg.eapi, pkg=pkg)
 
+        if eapi_str in self.options.target_repo.config.eapis_testing:
+            stable_keywords_gen = (k for k in pkg.keywords if not k.startswith(('~', '-')))
+            if stable_keywords := sorted(stable_keywords_gen):
+                yield StableKeywordsOnTestingEapi(pkg.eapi, stable_keywords, pkg=pkg)
+
         for eclass in pkg.inherit:
             if eclass_obj := self.eclass_cache.get(eclass):
                 if eclass_obj.supported_eapis and eapi_str not in eclass_obj.supported_eapis:
@@ -688,14 +734,20 @@ class InvalidBdepend(results.MetadataError, results.VersionResult):
     attr = 'bdepend'
 
 
+class InvalidIdepend(results.MetadataError, results.VersionResult):
+    """Package has invalid IDEPEND."""
+
+    attr = 'idepend'
+
+
 class DependencyCheck(Check):
-    """Check BDEPEND, DEPEND, RDEPEND, and PDEPEND."""
+    """Verify dependency attributes (e.g. RDEPEND)."""
 
     required_addons = (addons.UseAddon,)
     known_results = frozenset([
         BadDependency, MissingPackageRevision, MissingUseDepDefault,
         UnstatedIuse, DeprecatedDep, InvalidDepend, InvalidRdepend,
-        InvalidPdepend, InvalidBdepend,
+        InvalidPdepend, InvalidBdepend, InvalidIdepend,
     ])
 
     def __init__(self, *args, use_addon):
@@ -749,7 +801,10 @@ class DependencyCheck(Check):
                     # purpose of deprecations is to get rid of dependencies
                     # holding them in the repo.
                     if not atom.blocks and self.deprecated(atom):
-                        deprecated[attr].add(atom)
+                        # verify all matching packages are deprecated
+                        pkgs = self.options.search_repo.match(atom.no_usedeps)
+                        if all(self.deprecated(x.versioned_atom) for x in pkgs):
+                            deprecated[attr].add(atom)
 
                     if in_or_restriction and atom.slot_operator == '=':
                         yield BadDependency(
